# Life after filoma

Here are some tools and next steps that can complement `filoma` for further data analysis.

1. Use standard DataFrame tooling (Polars or Pandas) to analyze and visualize data extracted by `filoma`.
2. If you run any optional examples, install their dependencies locally; these are not required to use the core library.
